@@ -58,12 +58,13 @@ const (
 	SJWTRetErrJSONSignatureHashing  = -252
 	SJWTRetErrJSONSignatureSize     = -253
 	SJWTRetErrJSONSignatureFailure  = -254
+	SJWTRetErrJSONSignatureNob64  = -255
 	// identity SIP header errors: -300..-399
 	SJWTRetErrSIPHdrParse = -301
 	SJWTRetErrSIPHdrAlg   = -302
 	SJWTRetErrSIPHdrPpt   = -303
-	SJWTRetErrSIPHdrInfo  = -303
 	SJWTRetErrSIPHdrEmpty = -304
+	SJWTRetErrSIPHdrInfo  = -305
 	// http and file operations errors: -400..-499
 	SJWTRetErrHTTPInvalidURL = -401
 	SJWTRetErrHTTPGet        = -402
@@ -533,7 +534,7 @@ func SJWTVerifyWithPubKey(signingString string, signature string, key interface{
 
 	var sig []byte
 	if sig, err = SJWTBase64DecodeBytes(signature); err != nil {
-		return -1, err
+		return SJWTRetErrJSONSignatureNob64, err
 	}
 
 	var ecdsaKey *ecdsa.PublicKey
@@ -669,6 +670,27 @@ func SJWTEncodeText(headerJSON string, payloadJSON string, prvkeyPath string) (s
 	return signingValue + "." + signatureValue, SJWTRetOK, nil
 }
 
+// SJWTEncodeTextWithPrvKey - encode header and payload to JWT with private key data
+func SJWTEncodeTextWithPrvKey(headerJSON string, payloadJSON string, prvkeyData string) (string, int, error) {
+	var ret int
+	var err error
+	var signatureValue string
+	var ecdsaPrvKey *ecdsa.PrivateKey
+
+
+	if ecdsaPrvKey, ret, err = SJWTParseECPrivateKeyFromPEM([]byte(prvkeyData)); err != nil {
+		return "", ret, err
+	}
+
+	signingValue := SJWTBase64EncodeString(strings.TrimSpace(headerJSON)) +
+		"." + SJWTBase64EncodeString(strings.TrimSpace(payloadJSON))
+	signatureValue, ret, err = SJWTSignWithPrvKey(signingValue, ecdsaPrvKey)
+	if err != nil {
+		return "", ret, fmt.Errorf("failed to build signature: %v", err)
+	}
+	return signingValue + "." + signatureValue, SJWTRetOK, nil
+}
+
 // SJWTCheckAttributes - implements the verify of attributes
 func SJWTCheckAttributes(bToken string, paramInfo string) (int, error) {
 	vHeader, err := SJWTBase64DecodeString(bToken)
